@@ -1,21 +1,6 @@
 # -*- coding: utf-8 -*-
-#
-# Copyright (C) 2011 mooz
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
+
+import six
 
 class SelectorCommand(object):
     """
@@ -95,7 +80,7 @@ class SelectorCommand(object):
         self.select_successor()
 
     def __get_all_mark_indices(self):
-        return xrange(self.model.results_count)
+        return six.moves.range(self.model.results_count)
 
     def mark_all(self):
         for mark_index in self.__get_all_mark_indices():
@@ -191,6 +176,19 @@ class SelectorCommand(object):
                                self.model.query[caret + 1:]
             self.forward_char()
 
+    def unnarrow(self):
+        """
+        Clears the query, but keeps the current line selected. Useful to
+        show context around a search match.
+        """
+        try:
+            original_index = self.model.results[self.model.index][2]
+        except IndexError:
+            original_index = 0
+        self.clear_query()
+        self.model.do_search("")
+        self.model.select_index(original_index)
+
     # ------------------------------------------------------------ #
     # Text > kill
     # ------------------------------------------------------------ #
@@ -216,6 +214,14 @@ class SelectorCommand(object):
         self.model.finder.case_insensitive = not self.model.finder.case_insensitive
         self.model.force_search()
 
+    def specify_split_query(self, split_query):
+        self.model.finder.split_query = split_query
+        self.model.force_search()
+
+    def toggle_split_query(self):
+        self.model.finder.split_query = not self.model.finder.split_query
+        self.model.force_search()
+
     def specify_finder(self, preferred_finder_class):
         self.model.remake_finder(preferred_finder_class)
         self.model.force_search()
